;;;; -*- Mode: Lisp; Syntax: ANSI-Common-Lisp; Base: 10 -*-
;;;; addendum.lisp

;;;; This file contains expressions extending
;;;; functionality of the S-XML package.

;;;; Michael E Sparks (mespar1@iastate.edu)
;;;; Last Modified: 28 January 2007

;;;; Copyright (c) 2007 Michael E Sparks
;;;; All rights reserved.
;;;;
;;;; You are granted the rights to distribute and use this software
;;;; as governed by the terms of the Lisp Lesser General Public License
;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.

(in-package :s-xml-toolsaq)

;;; Expressions specific to gthXML parsing.

(defparameter *string-comparator* 'string=
  ;; Because XML element/attribute identifiers in gthXML formatted
  ;; documents *should* observe case constraints, string= is used
  ;; when comparing strings.  Replace with a less stringent operator,
  ;; e.g., string-equal, if this is compromised, for whatever reason.
  "Alias for a string comparison operator to use in checking
XML element/attribute identifiers")

(defparameter *character-comparator* 'char=
  ;; Various data points in gthXML documents are single characters,
  ;; which *should* observe case constraints.  If this is compromised
  ;; for some reason, replace char= with a less stringent operator,
  ;; e.g., char-equal.
  "Alias for a character comparison operator to use for various purposes")

;;; These expressions *may* be in the S-XML distribution already,
;;; but as best as I could tell from looking through the documentation and
;;; sources, they are not.(?)
;;; Thus, please observe that the two following definitions are
;;; brittle w.r.t. implementation details of the S-XML distribution.
;;; Because S-XML comes bundled with ToolSAQ, and judging by the change
;;; logs and applications using the former, this should not ever be
;;; an issue, though.

(defun get-current-xmlns ()
  "Get the XML namespace associated with an XML element."
  (get-uri (cdar *namespaces*)))

(defun get-attr-value (attr attr-alist &key (test *string-comparator*))
  "Get the attribute associated with a value."
  (cdr (assoc attr attr-alist :test test)))
